/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.column;

import org.opengion.hayabusa.db.AbstractEditor;
import org.opengion.hayabusa.db.CellEditor;
import org.opengion.hayabusa.db.DBColumn;
import org.opengion.fukurou.util.XHTMLTag;
import org.opengion.fukurou.util.StringUtil;

/**
 * PN エディターは、カラムのデータをカラムのデータを品番情報(１１桁の文字列を３-５-３編集)する
 * 場合に使用するクラスです。
 *
 *  カラムの表示に必要な属性は, DBColumn オブジェクト より取り出します。
 * このクラスは、DBColumn オブジェクト毎に１つ作成されます。
 *
 * @og.group データ編集
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class Editor_PN extends AbstractEditor {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.0.0 (2005/08/31)" ;

	/**
	 * デフォルトコンストラクター。
	 * このコンストラクターで、基本オブジェクトを作成します。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 *
	 */
	public Editor_PN() {
		// 4.3.4.4 (2009/01/01)
//		super();
	}

	/**
	 * コンストラクター。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 * @og.rev 3.5.6.0 (2004/06/18) XHTMLTag の 内部配列 INPUT_KEY を隠蔽します。
	 *
	 * @param   clm DBColumn オブジェクト
	 */
	private Editor_PN( final DBColumn clm ) {
		super( clm );
		attributes.set( "onBlur" ,"value=replaceText(value,'-','');" );
		tagBuffer.add( XHTMLTag.inputAttri( attributes ) );
	}

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @param   clm DBColumn オブジェクト
	 * @return  CellEditor オブジェクト
	 */
	public CellEditor newInstance( final DBColumn clm ) {
		return new Editor_PN( clm );
	}

	/**
	 * データの編集用文字列を返します。<br />
	 * XXX-XXXXX-XXX 形式で入力された情報を、XXXXXXXXXXX 形式で編集します。
	 * カット＆ペースト対策です。
	 *
	 * @param   value String
	 * @return  データの編集用文字列
	 */
	public String getValue( final String value ) {
		String newVal = StringUtil.rTrim( value );

		if( newVal != null && newVal.indexOf( '-' ) >= 0 ) {
			newVal = StringUtil.replace( newVal,"-","" );
		}

		return super.getValue( newVal );
	}

	/**
	 * name属性を変えた、データ表示/編集用のHTML文字列を作成します。<br />
	 * テーブル上の name に 行番号を付加して、名前_行番号 で登録するキーを作成し,
	 * リクエスト情報を１つ毎のフィールドで処理できます。<br />
	 *
	 * @param   row   int 行番号
	 * @param   value String
	 * @return  データ表示/編集用の文字列
	 */
	public String getValue( final int row,final String value ) {
		String newVal = StringUtil.rTrim( value );

		if( newVal != null && newVal.indexOf( '-' ) >= 0 ) {
			newVal = StringUtil.replace( newVal,"-","" );
		}

		return super.getValue( row,newVal );
	}
}
